@@ -42,6 +42,7 @@
 #'   then \emph{to} it will be considered. If \code{all}, the default, then
 #'   the corresponding undirected graph will be used, ie. not directed paths
 #'   are searched. This argument is ignored for undirected graphs.
+#' @param cutoff Maximum length of path that is considered. If negative, paths of all lengths are considered.
 #' @return A list of integer vectors, each integer vector is a path from
 #'   the source vertex to one of the target vertices. A path is given by its
 #'   vertex ids.
@@ -55,7 +56,8 @@
 #' @export
 
 all_simple_paths <- function(graph, from, to = V(graph),
-                             mode = c("out", "in", "all", "total")) {
+                             mode = c("out", "in", "all", "total"),
+                             cutoff = -1) {
   ## Argument checks
   if (!is_igraph(graph)) stop("Not a graph object")
   from <- as.igraph.vs(graph, from)
@@ -67,7 +69,7 @@ all_simple_paths <- function(graph, from, to = V(graph),
 
   ## Function call
   res <- .Call(C_R_igraph_get_all_simple_paths, graph, from - 1, to - 1,
-                mode)
+               as.integer(cutoff), mode)
   res <- get.all.simple.paths.pp(res)
 
   if (igraph_opt("return.vs.es")) { 
